%bcond_without docs

%global pypi_name    borgbackup
%global pypi_version 1.2.0

Name:           %{pypi_name}
Version:        %{pypi_version}
Release:        4%{?dist}
Summary:        Deduplicated, encrypted, authenticated and compressed backups

License:        BSD
URL:            https://borgbackup.readthedocs.io/
Source0:        https://files.pythonhosted.org/packages/source/%(c=%{pypi_name}; echo ${c:0:1})/%{pypi_name}/%{pypi_name}-%{version}.tar.gz

BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_version}dist(setuptools)
BuildRequires:  python%{python3_version}dist(setuptools-scm) >= 1.7
BuildRequires:  python%{python3_version}dist(cython)
BuildRequires:  python%{python3_version}dist(pkgconfig)
BuildRequires:  gcc
BuildRequires:  libacl-devel
BuildRequires:  libzstd-devel
BuildRequires:  lz4-devel
BuildRequires:  openssl-devel
BuildRequires:  xxhash-devel

%if %{with docs}
BuildRequires:  python%{python3_version}dist(sphinx)
%endif

Requires:       python%{python3_version}dist(llfuse) >= 1.3.8
Requires:       (python%{python3_version}dist(msgpack) >= 0.5.6 with python%{python3_version}dist(msgpack) <= 1.0.3 with (python%{python3_version}dist(msgpack) < 1.0.1 or python%{python3_version}dist(msgpack) > 1.0.1))
Requires:       python%{python3_version}dist(packaging)
Requires:       python%{python3_version}dist(setuptools)

%description
BorgBackup (short: Borg) is a deduplicating backup program. Optionally, it
supports compression and authenticated encryption.


%if %{with docs}
%package -n python-%{pypi_name}-doc
Summary:        borgbackup documentation

%description -n python-%{pypi_name}-doc
Documentation for borgbackup
%endif


%prep
%autosetup -n %{pypi_name}-%{pypi_version}
rm -rf %{pypi_name}.egg-info

# Remove copies of bundled libraries to ensure these don't end up in our
# binaries.
rm -rf src/borg/algorithms/{lz4,xxh64,zstd}

# Remove precompiled Cython code to ensure we always built "from source".
find src/ -name '*.pyx' | sed -e 's/.pyx/.c/g' | xargs rm -f

%build
%py3_build

%if %{with docs}
PYTHONPATH=${PWD} sphinx-build-3 docs html
rm -rf html/.{doctrees,buildinfo}
%endif

%install
%py3_install

%files -n %{pypi_name}
%license LICENSE
%doc README.rst docs/3rd_party/blake2/README.md
%{_bindir}/borg
%{_bindir}/borgfs
%{python3_sitearch}/borg
%{python3_sitearch}/%{pypi_name}-%{pypi_version}-py%{python3_version}.egg-info


%if %{with docs}
%files -n python-%{pypi_name}-doc
%doc html
%license LICENSE
%endif

%changelog
* Wed Apr 20 2022 Daniel Uvehag <ufven+pkgs@protonmail.com> - 1.2.0-4
- Remove pyfuse3 as llfuse is already provided

* Wed Apr 20 2022 Daniel Uvehag <ufven+pkgs@protonmail.com> - 1.2.0-3
- Added missing gcc build dependency

* Wed Apr 20 2022 Daniel Uvehag <ufven+pkgs@protonmail.com> - 1.2.0-2
- Removed bundled algorithms
- Removed precompiled Cython files, and added Cython as a dependency

* Tue Apr 19 2022 Daniel Uvehag <ufven+pkgs@protonmail.com> - 1.2.0-1
- Initial package.
